---
name: 📚 Documentation
about: Report an issue related to documentation
labels: 'documentation, needs triage'
---

## 📚 Documentation

(A clear and concise description of what the issue is.)

### Have you read the [Contributing Guidelines on issues](https://github.com/zenorocha/clipboard.js/blob/master/contributing.md)?

(Write your answer here.)
